@@ -45,6 +45,9 @@ def partition_html(
     parser
         The parser to use for parsing the HTML document. If None, default parser will be used.
     """
+    if text is not None and text.strip() == "" and not file and not filename and not url:
+        return []
+
     # Verify that only one of the arguments was provided
     exactly_one(filename=filename, file=file, text=text, url=url)
 
